jQuery(document).ready(function( J ) {
  J( '.control a' ).tipsy({ gravity : 'sw' });
  init_accept_reject();
  init_reset_buttons();
  init_change_date();
})

function init_accept_reject() {
  jQuery( 'td.control a.accept.one:not(.disabled)' ).click( function() {
    return change_resource_difference( jQuery( this ), 'accepted', 'rejected' );
  });
  jQuery( 'td.control a.reject.one:not(.disabled)' ).click( function() {
    return change_resource_difference( jQuery( this ), 'rejected', 'accepted' );
  });

  jQuery( '.control.accept.all a' ).click( function() {
    return change_all_resource_differences( jQuery( this ), 'accepted', 'rejected' );
  });
  jQuery( '.control.reject.all a' ).click( function() {
    return change_all_resource_differences( jQuery( this ), 'rejected', 'accepted' );
  });

  jQuery( '.show-audited-properties' ).click( function() {
    return show_audited_properties_for( jQuery( this ) )
  });
}

function init_reset_buttons() {
  jQuery( 'button.reset' ).live('click', function(self) {
    jQuery( this ).parent().clearForm();
  });
}

function init_change_date() {
  var select = jQuery( '#change_date' );
  select.change( function() {
    if ( select.find( ':selected' ).text().match( /^[0-9]/ ) ) {
      select.closest('form').submit();
    }
  });
}

function change_resource_difference( link, to, from ) {
  var href = link.attr( 'href' );

  jQuery.ajax({
    url: href,
    beforeSend: function() { resource_difference_before( link, to, from ) },
    error: function() { resource_difference_error( link, to, from ) },
    success: function(result) { resource_difference_success( link, to, from ); update_resource_counts(result); },
  });

  return false;
}

function change_all_resource_differences( link, to, from ) {
  var href = link.attr( 'href' );
  var parent = link.parent();

  // We have an up-to-date conflict count on the accept/reject div, supplied
  // by our controller and maintained by AJAX updates.  So, reference that
  // when someone asks us to take this action...
  var source = jQuery( 'div#accept_reject_all' )
  var conflicts = parseInt( source.attr( from ), 10 )
  var always_prompt = source.attr( "always_prompt" ) != "false"
  var text = conflicts == 1 ? "the difference" : "the "+conflicts+" differences"
  var qn = "This will overwrite "+text+" that you have already "+from+".\n\nContinue?";

  if ((conflicts == 0 && !always_prompt) || confirm(qn)) {
    jQuery.ajax({
      url: href,
      beforeSend: function() { resource_difference_before( parent, to, from ) },
      error: function() { resource_difference_error( parent, to, from ) },
      success: function(result) { update_all_differences( parent, to, from ); update_resource_counts(result); },
    });
  }

  return false;
}

function resource_difference_before( link, to, from ) {
  link.addClass( 'loading' );
}

function resource_difference_success( link, to, from ) {
  var row = link.closest( 'tbody' );
  row
    .removeClass( 'no-action' )
    .removeClass( from )
    .addClass( to );
  link.removeClass( 'loading' );
}

function update_all_differences( link, to, from ) {
  var container = jQuery( '.resource-container' );
  container
    .removeClass( 'no-action' )
    .removeClass( from )
    .addClass( to );
  link.removeClass( 'loading' );
}

function update_resource_counts(status_counts) {
  jQuery('dd.accepted').text(status_counts.accepted);
  jQuery('dd.rejected').text(status_counts.rejected);

  var unreviewed_text = status_counts.unreviewed;

  if (status_counts.unreviewed_nodes != null) {
    unreviewed_text = status_counts.unreviewed_nodes + ' nodes, ' + status_counts.unreviewed + ' differences';
  }

  jQuery('dd.unreviewed').text(unreviewed_text);

  // In the event this div doesn't exist, jQuery will silently do nothing
  // here; this makes this work sanely on the group page too.
  jQuery('div#accept_reject_all').attr(status_counts)
}

function resource_difference_error( link, to, from ) {
  alert( 'ERROR!' );
}

// AJAX-ishly fetch the full set of properties for a resource, and push 'em
// into place in the DOM.
function show_audited_properties_for( link ) {
  var comparisons_table = link.parent().next();
  link.click( function() { return false; });

  // Replace our current content with the full set of attributes...
  jQuery.ajax({
    url: link.attr('href'),
    beforeSend: function() {
      link.addClass( 'loading' );
    },
    success: function(result) {
      link.hide();
      var html = jQuery(result).children().last();
      comparisons_table.append( result );
    },
    error: function() { alert("failed to fetch data"); }
  });

  // Prevent the click going anywhere else...
  return false;
}
